package com.fs.task.service;

import java.util.List;
import com.fs.task.domain.TaskDeliveryInfo;

/**
 * 交付物信息Service接口
 * 
 * @author fs
 * @date 2026-01-04
 */
public interface ITaskDeliveryInfoService 
{
    /**
     * 查询交付物信息
     * 
     * @param id 交付物信息主键
     * @return 交付物信息
     */
    public TaskDeliveryInfo selectTaskDeliveryInfoById(Long id);

    /**
     * 查询交付物信息列表
     * 
     * @param taskDeliveryInfo 交付物信息
     * @return 交付物信息集合
     */
    public List<TaskDeliveryInfo> selectTaskDeliveryInfoList(TaskDeliveryInfo taskDeliveryInfo);

    /**
     * 新增交付物信息
     * 
     * @param taskDeliveryInfo 交付物信息
     * @return 结果
     */
    public int insertTaskDeliveryInfo(TaskDeliveryInfo taskDeliveryInfo);

    /**
     * 修改交付物信息
     * 
     * @param taskDeliveryInfo 交付物信息
     * @return 结果
     */
    public int updateTaskDeliveryInfo(TaskDeliveryInfo taskDeliveryInfo);

    /**
     * 批量删除交付物信息
     * 
     * @param ids 需要删除的交付物信息主键集合
     * @return 结果
     */
    public int deleteTaskDeliveryInfoByIds(Long[] ids);

    /**
     * 删除交付物信息信息
     * 
     * @param id 交付物信息主键
     * @return 结果
     */
    public int deleteTaskDeliveryInfoById(Long id);

    TaskDeliveryInfo  getDeliveryInfoByTaskTypeAndDeliveryNo(TaskDeliveryInfo taskDeliveryInfo);

}
